@@ -11,20 +11,19 @@
 # The cache is stored in $libdir/facts_dot_d.cache as a mode
 # 600 file and will have the end result of not calling your
 # fact scripts more often than is needed
-
 class Facter::Util::DotD
   require 'yaml'
 
-  def initialize(dir="/etc/facts.d", cache_file=File.join(Puppet[:libdir], "facts_dot_d.cache"))
+  def initialize(dir = '/etc/facts.d', cache_file = File.join(Puppet[:libdir], 'facts_dot_d.cache'))
     @dir = dir
     @cache_file = cache_file
     @cache = nil
-    @types = {".txt" => :txt, ".json" => :json, ".yaml" => :yaml}
+    @types = { '.txt' => :txt, '.json' => :json, '.yaml' => :yaml }
   end
 
   def entries
-    Dir.entries(@dir).reject { |f| f =~ /^\.|\.ttl$/ }.sort.map { |f| File.join(@dir, f) }
-  rescue
+    Dir.entries(@dir).reject { |f| f =~ %r{^\.|\.ttl$} }.sort.map { |f| File.join(@dir, f) }
+  rescue # rubocop:disable Lint/RescueWithoutErrorClass
     []
   end
 
@@ -35,17 +34,17 @@ class Facter::Util::DotD
 
     type = :script if type == :unknown && File.executable?(file)
 
-    return type
+    type
   end
 
   def txt_parser(file)
     File.readlines(file).each do |line|
-      if line =~ /^([^=]+)=(.+)$/
-        var = $1; val = $2
+      next unless line =~ %r{^([^=]+)=(.+)$}
+      var = Regexp.last_match(1)
+      val = Regexp.last_match(2)
 
-        Facter.add(var) do
-          setcode { val }
-        end
+      Facter.add(var) do
+        setcode { val }
       end
     end
   rescue StandardError => e
@@ -60,7 +59,7 @@ class Facter::Util::DotD
       raise
     end
 
-    JSON.load(File.read(file)).each_pair do |f, v|
+    JSON.parse(File.read(file)).each_pair do |f, v|
       Facter.add(f) do
         setcode { v }
       end
@@ -85,7 +84,9 @@ class Facter::Util::DotD
     result = cache_lookup(file)
     ttl = cache_time(file)
 
-    unless result
+    if result
+      Facter.debug("Using cached data for #{file}")
+    else
       result = Facter::Util::Resolution.exec(file)
 
       if ttl > 0
@@ -93,17 +94,15 @@ class Facter::Util::DotD
         cache_store(file, result)
         cache_save!
       end
-    else
-      Facter.debug("Using cached data for #{file}")
     end
 
     result.split("\n").each do |line|
-      if line =~ /^(.+)=(.+)$/
-        var = $1; val = $2
+      next unless line =~ %r{^(.+)=(.+)$}
+      var = Regexp.last_match(1)
+      val = Regexp.last_match(2)
 
-        Facter.add(var) do
-          setcode { val }
-        end
+      Facter.add(var) do
+        setcode { val }
       end
     end
   rescue StandardError => e
@@ -113,15 +112,15 @@ class Facter::Util::DotD
 
   def cache_save!
     cache = load_cache
-    File.open(@cache_file, "w", 0600) { |f| f.write(YAML.dump(cache)) }
-  rescue
+    File.open(@cache_file, 'w', 0o600) { |f| f.write(YAML.dump(cache)) }
+  rescue # rubocop:disable Lint/HandleExceptions, Lint/RescueWithoutErrorClass
   end
 
   def cache_store(file, data)
     load_cache
 
-    @cache[file] = {:data => data, :stored => Time.now.to_i}
-  rescue
+    @cache[file] = { :data => data, :stored => Time.now.to_i }
+  rescue # rubocop:disable Lint/HandleExceptions, Lint/RescueWithoutErrorClass
   end
 
   def cache_lookup(file)
@@ -131,38 +130,33 @@ class Facter::Util::DotD
 
     ttl = cache_time(file)
 
-    if cache[file]
-      now = Time.now.to_i
+    return nil unless cache[file]
+    now = Time.now.to_i
 
-      return cache[file][:data] if ttl == -1
-      return cache[file][:data] if (now - cache[file][:stored]) <= ttl
-      return nil
-    else
-      return nil
-    end
-  rescue
+    return cache[file][:data] if ttl == -1
+    return cache[file][:data] if (now - cache[file][:stored]) <= ttl
+    return nil
+  rescue # rubocop:disable Lint/RescueWithoutErrorClass
     return nil
   end
 
   def cache_time(file)
-    meta = file + ".ttl"
+    meta = file + '.ttl'
 
     return File.read(meta).chomp.to_i
-  rescue
+  rescue # rubocop:disable Lint/RescueWithoutErrorClass
     return 0
   end
 
   def load_cache
-    unless @cache
-      if File.exist?(@cache_file)
-        @cache = YAML.load_file(@cache_file)
-      else
-        @cache = {}
-      end
-    end
+    @cache ||= if File.exist?(@cache_file)
+                 YAML.load_file(@cache_file)
+               else
+                 {}
+               end
 
     return @cache
-  rescue
+  rescue # rubocop:disable Lint/RescueWithoutErrorClass
     @cache = {}
     return @cache
   end
@@ -172,28 +166,26 @@ class Facter::Util::DotD
       type = fact_type(fact)
       parser = "#{type}_parser"
 
-      if respond_to?("#{type}_parser")
-        Facter.debug("Parsing #{fact} using #{parser}")
+      next unless respond_to?("#{type}_parser")
+      Facter.debug("Parsing #{fact} using #{parser}")
 
-        send(parser, fact)
-      end
+      send(parser, fact)
     end
   end
 end
 
-
-mdata = Facter.version.match(/(\d+)\.(\d+)\.(\d+)/)
+mdata = Facter.version.match(%r{(\d+)\.(\d+)\.(\d+)})
 if mdata
-  (major, minor, patch) = mdata.captures.map { |v| v.to_i }
+  (major, minor, _patch) = mdata.captures.map { |v| v.to_i }
   if major < 2
     # Facter 1.7 introduced external facts support directly
-    unless major == 1 and minor > 6
-      Facter::Util::DotD.new("/etc/facter/facts.d").create
-      Facter::Util::DotD.new("/etc/puppetlabs/facter/facts.d").create
+    unless major == 1 && minor > 6
+      Facter::Util::DotD.new('/etc/facter/facts.d').create
+      Facter::Util::DotD.new('/etc/puppetlabs/facter/facts.d').create
 
       # Windows has a different configuration directory that defaults to a vendor
       # specific sub directory of the %COMMON_APPDATA% directory.
-      if Dir.const_defined? 'COMMON_APPDATA' then
+      if Dir.const_defined? 'COMMON_APPDATA' # rubocop:disable Metrics/BlockNesting : Any attempt to alter this breaks it
         windows_facts_dot_d = File.join(Dir::COMMON_APPDATA, 'PuppetLabs', 'facter', 'facts.d')
         Facter::Util::DotD.new(windows_facts_dot_d).create
       end
