@@ -1,11 +1,11 @@
-#! /usr/bin/env ruby -S rspec
+#! /usr/bin/env ruby -S rspec # rubocop:disable Lint/ScriptPermission : Rubocop error??
 require 'spec_helper'
 require 'puppet/type'
 require 'puppet/type/package'
 
 describe 'package_provider', :type => :fact do
-  before { Facter.clear }
-  after { Facter.clear }
+  before(:each) { Facter.clear }
+  after(:each) { Facter.clear }
 
   ['4.2.2', '3.7.1 (Puppet Enterprise 3.2.1)'].each do |puppetversion|
     describe "on puppet ''#{puppetversion}''" do
@@ -13,8 +13,8 @@ describe 'package_provider', :type => :fact do
         Facter.stubs(:value).returns puppetversion
       end
 
-      context "darwin" do
-        it "should return pkgdmg" do
+      context 'when darwin' do
+        it 'returns pkgdmg' do
           provider = Puppet::Type.type(:package).provider(:pkgdmg)
           Puppet::Type.type(:package).stubs(:defaultprovider).returns provider
 
@@ -22,8 +22,8 @@ describe 'package_provider', :type => :fact do
         end
       end
 
-      context "centos 7" do
-        it "should return yum" do
+      context 'when centos 7' do
+        it 'returns yum' do
           provider = Puppet::Type.type(:package).provider(:yum)
           Puppet::Type.type(:package).stubs(:defaultprovider).returns provider
 
@@ -31,8 +31,8 @@ describe 'package_provider', :type => :fact do
         end
       end
 
-      context "ubuntu" do
-        it "should return apt" do
+      context 'when ubuntu' do
+        it 'returns apt' do
           provider = Puppet::Type.type(:package).provider(:apt)
           Puppet::Type.type(:package).stubs(:defaultprovider).returns provider
 
