@@ -1,14 +1,14 @@
-#! /usr/bin/env ruby -S rspec
+#! /usr/bin/env ruby -S rspec # rubocop:disable Lint/ScriptPermission : Rubocop error??
 require 'spec_helper'
 require 'puppet/type'
 require 'puppet/type/service'
 
 describe 'service_provider', :type => :fact do
-  before { Facter.clear }
-  after { Facter.clear }
+  before(:each) { Facter.clear }
+  after(:each) { Facter.clear }
 
-  context "macosx" do
-    it "should return launchd" do
+  context 'when macosx' do
+    it 'returns launchd' do
       provider = Puppet::Type.type(:service).provider(:launchd)
       Puppet::Type.type(:service).stubs(:defaultprovider).returns provider
 
@@ -16,8 +16,8 @@ describe 'service_provider', :type => :fact do
     end
   end
 
-  context "systemd" do
-    it "should return systemd" do
+  context 'when systemd' do
+    it 'returns systemd' do
       provider = Puppet::Type.type(:service).provider(:systemd)
       Puppet::Type.type(:service).stubs(:defaultprovider).returns provider
 
@@ -25,13 +25,12 @@ describe 'service_provider', :type => :fact do
     end
   end
 
-  context "redhat" do
-    it "should return redhat" do
+  context 'when redhat' do
+    it 'returns redhat' do
       provider = Puppet::Type.type(:service).provider(:redhat)
       Puppet::Type.type(:service).stubs(:defaultprovider).returns provider
 
       expect(Facter.fact(:service_provider).value).to eq('redhat')
     end
   end
-
 end
